@@ -115,6 +115,9 @@ class PythonExecutor:
             sink = self.table(context.columns)
 
         for reader in table_iter:
+            if len(sink) >= step.limit:
+                break
+
             if condition and not context.eval(condition):
                 continue
 
@@ -123,9 +126,6 @@ class PythonExecutor:
             else:
                 sink.append(reader.row)
 
-            if len(sink) >= step.limit:
-                break
-
         return self.context({step.name: sink})
 
     def static(self):
@@ -294,19 +294,25 @@ class PythonExecutor:
             if not condition or context.eval(condition):
                 table.append(group + context.eval_tuple(aggregations))
 
-        for i in range(length):
-            context.set_index(i)
-            key = context.eval_tuple(group_by)
-            group = key if group is None else group
-            end += 1
-            if key != group:
-                context.set_range(start, end - 2)
-                add_row()
-                group = key
-                start = end - 2
-            if i == length - 1:
-                context.set_range(start, end - 1)
-                add_row()
+        if length:
+            for i in range(length):
+                context.set_index(i)
+                key = context.eval_tuple(group_by)
+                group = key if group is None else group
+                end += 1
+                if key != group:
+                    context.set_range(start, end - 2)
+                    add_row()
+                    group = key
+                    start = end - 2
+                if len(table.rows) >= step.limit:
+                    break
+                if i == length - 1:
+                    context.set_range(start, end - 1)
+                    add_row()
+        elif step.limit > 0:
+            context.set_range(0, 0)
+            table.append(context.eval_tuple(group_by) + context.eval_tuple(aggregations))
 
         context = self.context({step.name: table, **{name: table for name in context.tables}})
 
